@@ -15,8 +15,8 @@ from tqdm.auto import tqdm
 
 from .data_handlers import clean_forecast_csv
 from .downloader_helpers.data import MMSDM_ARCHIVE_URL, USER_AGENTS
-from .loader import (
-    Loader,
+from .query import (
+    Query,
     _construct_sqlloader_filename,
     _enumerate_tables,
     generate_sqlloader_filenames,
@@ -293,6 +293,7 @@ def get_unzipped_csv(url: str, raw_cache: Path) -> None:
         and (fn.group(1) == zfn.group(1))
     ):
         z.extractall(raw_cache)
+        z.close()
         Path(file_path).unlink()
     else:
         raise ValueError(f"Unexpected contents in zipfile from {url}")
@@ -302,7 +303,7 @@ def _validate_tables_on_forecast_start(instance, attribute, value):
     """Validates tables for the provided forecast type.
 
     Checks user-supplied tables against tables available in MMS Historical
-    Data SQL Loader for the month and year of forecast_start.
+    Data SQLLoader for the month and year of forecast_start.
     """
     start_dt = instance.forecast_start
     tables = _get_all_sqlloader_forecast_tables(
@@ -325,18 +326,18 @@ class ForecastTypeDownloader:
     raw_cache: Optional[str] = field(default=None)
 
     @classmethod
-    def from_Loader(cls, loader: Loader):
-        """Constructor method for ForecastTypeDownloader from Loader."""
-        tables = loader.tables
-        if "CONSTRAINTSOLUTION" in tables and loader.forecast_type == "P5MIN":
+    def from_Query(cls, query: Query):
+        """Constructor method for ForecastTypeDownquery from Query."""
+        tables = query.tables
+        if "CONSTRAINTSOLUTION" in tables and query.forecast_type == "P5MIN":
             tables = _enumerate_tables(tables, "CONSTRAINTSOLUTION", 4)
 
         return cls(
-            forecast_start=loader.forecast_start,
-            forecast_end=loader.forecast_end,
-            forecast_type=loader.forecast_type,
+            forecast_start=query.forecast_start,
+            forecast_end=query.forecast_end,
+            forecast_type=query.forecast_type,
             tables=tables,
-            raw_cache=loader.raw_cache,
+            raw_cache=query.raw_cache,
         )
 
     def download_csv(self):
@@ -374,9 +375,12 @@ class ForecastTypeDownloader:
                     f"Attempting to convert {csv} to parquet,"
                     + " but your available system memory may be too low for this."
                 )
-            logging.info(f"Converting {csv.name} to parquet")
             df = clean_forecast_csv(csv)
             parquet_name = csv.name[0:-3] + "parquet"
-            df.to_parquet(csv.with_name(parquet_name))
+            if not csv.with_name(parquet_name).exists():
+                logging.info(f"Converting {csv.name} to parquet")
+                df.to_parquet(csv.with_name(parquet_name))
+            else:
+                logging.info(f"{parquet_name} already exists")
             if not keep_csv:
                 csv.unlink()
